import React, { useState } from 'react';
import { Button, Tooltip, TooltipContent, TooltipProvider, TooltipTrigger } from '../components';
import { Fullscreen, Schema as SchemaIcon, Search as SearchIcon } from '@mui/icons-material';
import ColorMode from '../components/color-mode';

export type SideNavTab = 'Schema' | 'Search' | undefined;
const tabs: Array<{
  name: SideNavTab;
  icon: JSX.Element;
}> = [
  {
    name: 'Search',
    icon: <SearchIcon />,
  },
  { name: 'Schema', icon: <SchemaIcon /> },
];

export function Sidebar({ onTab }: { onTab: (tab: SideNavTab) => void }) {
  const [tab, setTab] = useState<SideNavTab>('Schema');

  return (
    <div className="info-panel w-fit h-full flex flex-shrink">
      <TooltipProvider delayDuration={100}>
        <div className="w-12 flex flex-col items-center justify-between">
          <div className="flex flex-col items-center justify-between">
            {tabs.map((t) => (
              <Tooltip key={t.name}>
                <TooltipTrigger>
                  <Button
                    type="secondary"
                    variant="ghost"
                    size="md"
                    iconComponent={t.icon}
                    onClick={() => {
                      if (tab === t.name) {
                        onTab(undefined);
                        setTab(undefined);
                      } else {
                        onTab(t.name);
                        setTab(t.name);
                      }
                    }}
                    additionalClasses={tab === t.name ? 'bg-secondary-100' : ''}
                  />
                </TooltipTrigger>
                <TooltipContent side={'right'}>{t.name}</TooltipContent>
              </Tooltip>
            ))}
          </div>
          <ColorMode />
        </div>
      </TooltipProvider>
    </div>
  );
}
