import React from 'react';
import { locationMap, typesMap } from './HeatLayer';

type Props = {
  layer: any;
  updatedLayer: any;
  graphInfo: any;
  deleteLayer: any;
};

export default function HeatLayerOptions({ layer, updatedLayer, graphInfo, deleteLayer }: Props) {
  console.log(layer.config);

  return (
    <div>
      <div className="divider m-0"></div>

      <div>
        <select
          className="select select-bordered w-full max-w-xs"
          value={layer.config.type}
          onChange={(e) =>
            updatedLayer(layer.id, {
              config: {
                ...layer.config,
                type: e.target.value,
              },
            })
          }
        >
          <option disabled selected>
            Type
          </option>
          {typesMap.map((type) => (
            <option key={type} value={type}>
              {type}
            </option>
          ))}
        </select>

        {layer.config.type !== 'path' && layer.config.type !== 'attribute' && (
          <select
            className="select select-bordered w-full max-w-xs"
            value={layer.config.location}
            onChange={(e) =>
              updatedLayer(layer.id, {
                config: {
                  ...layer.config,
                  location: e.target.value,
                },
              })
            }
          >
            <option disabled selected>
              Node
            </option>
            {locationMap.map((type) => (
              <option key={type} value={type}>
                {type}
              </option>
            ))}
          </select>
        )}

        {layer.config.type === 'path' && (
          <div className="p-2">
            <p>Number of segments</p>
            <div style={{ display: 'flex', justifyContent: 'space-between' }}>
              <input
                className="range"
                type="range"
                min={1}
                max={20}
                value={layer.config.nSegments}
                onChange={(e) =>
                  updatedLayer(layer.id, {
                    config: {
                      ...layer.config,
                      nSegments: e.target.value,
                    },
                  })
                }
              />
              <p>{layer.config.nSegments}</p>
            </div>
          </div>
        )}

        {layer.config.type === 'attribute' && (
          <>
            <select
              className="select select-bordered w-full max-w-xs"
              value={layer.config.entity}
              onChange={(e) =>
                updatedLayer(layer.id, {
                  config: {
                    ...layer.config,
                    entity: e.target.value,
                  },
                })
              }
            >
              <option disabled selected>
                Entity
              </option>
              <option value={'nodeAttributes'}>Node</option>
              <option value={'edgeAttributes'}>Edge</option>
            </select>

            <select
              className="select select-bordered w-full max-w-xs"
              value={layer.config.attribute}
              onChange={(e) =>
                updatedLayer(layer.id, {
                  config: {
                    ...layer.config,
                    attribute: e.target.value,
                  },
                })
              }
            >
              <option disabled selected>
                Attribute
              </option>
              {Object.keys(graphInfo[layer.config.entity]).map((value) => (
                <option key={value} value={value}>
                  {value}
                </option>
              ))}
            </select>
          </>
        )}
      </div>

      <div className="divider m-0"></div>

      <div>
        <button
          className="btn btn-primary w-full"
          onClick={() =>
            updatedLayer(layer.id, {
              visible: !layer.visible,
            })
          }
        >
          {layer.visible ? 'Hide layer' : 'Show layer'}
        </button>

        <button className="btn btn-outline btn-primary w-full mt-1" onClick={() => deleteLayer(layer.id)}>
          Delete layer
        </button>
      </div>
    </div>
  );
}
