import { tailwindColors } from 'config';
import { GraphType, LinkType, NodeType } from '../types';

/**
 * Colour is a function that takes a string of a number and returns a number of a color out of the d3 color scheme.
 * @param num Num is the input string representing a number of a colorgroup.
 * @returns {number} A number corresponding to a color in the d3 color scheme.
 */
export function nodeColor(num: number) {
  // num = num % 4;
  // const col = '#000000';
  const col = tailwindColors.custom.nodes[num % (tailwindColors.custom.nodes.length - 1)];
  return binaryColor(col);
}

export function binaryColor(color: string) {
  return Number('0x' + color.replace('#', ''));
}

/**
 * Used when you select nodes.
 * The highlight is drawn in ticked.
 * @param nodes The nodes you want to related edges to.
 * @returns {LinkType[]} All the links related to all the nodes
 */
export const getRelatedLinks = (graph: GraphType, nodes: NodeType[], jaccardThreshold: number): LinkType[] => {
  const relatedLinks: LinkType[] = [];
  graph.links.forEach((link: LinkType) => {
    const { source, target } = link;
    if (isLinkVisible(link, jaccardThreshold)) {
      nodes.forEach((node: NodeType) => {
        if (source == node || target == node || source == node.id || target == node.id) {
          relatedLinks.push(link);
        }
      });
    }
  });
  return relatedLinks;
};

/**
 * Checks wheter a link is visible.
 * This is used for highlighting nodes.
 * @param link The link you want to check wheter it's visable or not
 * @returns {boolean}
 */
export function isLinkVisible(link: LinkType, jaccardThreshold: number): boolean {
  //About the next line, If you don't do this here but lets say in the constructor it errors. So far no performance issues where noticed.
  if (link.mlEdge) {
    if (link.value > jaccardThreshold) {
      return true;
    }
  } else return true;
  return false;
}
